==> haskell-postgresql-binary-0.9.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.9.1
id: postgresql-binary-0.9.1-A4HnK8uD3T9LF4wTlS7QwC
key: postgresql-binary-0.9.1-A4HnK8uD3T9LF4wTlS7QwC
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.4
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoder
    PostgreSQL.Binary.Encoder
hidden-modules: PostgreSQL.Binary.Prelude
                PostgreSQL.Binary.Integral PostgreSQL.Binary.Interval
                PostgreSQL.Binary.Numeric PostgreSQL.Binary.Time
                PostgreSQL.Binary.BuilderPrim
abi: a9a2b19eaefaa3a1e8f8714fda64fb55
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/postgresql-binary-0.9.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/postgresql-binary-0.9.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/postgresql-binary-0.9.1
hs-libraries: HSpostgresql-binary-0.9.1-A4HnK8uD3T9LF4wTlS7QwC
depends:
    aeson-0.11.2.0-31ZI7bFuFz27ynqHifCKlM base-4.9.0.0
    base-prelude-1.0.1.1-50PByGWQp6O3J1SglYyZmP
    binary-parser-0.5.2-EDprLoBQcOu94TGhdmaB5o bytestring-0.10.8.1
    foldl-1.2.1-C8E5tabgEltAqBa6qUkd7Q
    loch-th-0.2.1-HeAYtId6vjrGaOk8hiaVQf
    placeholders-0.1-Jaw2KlzCEKg3F0WJS0H8eo
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0 uuid-1.3.12-BC5jDMyqaqLOzx28bJruV
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-binary-0.9.2-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.9.2
id: postgresql-binary-0.9.2-3Kep5PzLfKKIfURW7DHyax
key: postgresql-binary-0.9.2-3Kep5PzLfKKIfURW7DHyax
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoder
    PostgreSQL.Binary.Encoder
hidden-modules: PostgreSQL.Binary.Prelude
                PostgreSQL.Binary.Integral PostgreSQL.Binary.Interval
                PostgreSQL.Binary.Numeric PostgreSQL.Binary.Time
                PostgreSQL.Binary.BuilderPrim
abi: e894a20e51d51c9df983f520e19e9e82
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/postgresql-binary-0.9.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/postgresql-binary-0.9.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/postgresql-binary-0.9.2
hs-libraries: HSpostgresql-binary-0.9.2-3Kep5PzLfKKIfURW7DHyax
depends:
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx base-4.9.0.0
    base-prelude-1.0.1.1-50PByGWQp6O3J1SglYyZmP
    binary-parser-0.5.2-EDprLoBQcOu94TGhdmaB5o bytestring-0.10.8.1
    foldl-1.2.3-79eswbd8l2Q5ZY7g2Wzg7
    loch-th-0.2.1-HeAYtId6vjrGaOk8hiaVQf
    placeholders-0.1-Jaw2KlzCEKg3F0WJS0H8eo
    scientific-0.3.4.10-HyHkymmV2uwD8dEKuPMVuU
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0 uuid-1.3.13-LNkd6YXQyKMLQFcm1B39cg
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
